import os
import json
import click
import arrow
from jira import JIRA


def format_time(time_string):
    time = arrow.get(time_string)
    return time.format('YYYY-MM-DD HH:mm:ss ZZ')


def get_timedelta(begin, end):
    arrow_begin = arrow.get(begin)
    arrow_end = arrow.get(end)

    return arrow_end - arrow_begin


def create_jira():
    config = get_config()

    if set(['server', 'user', 'password']).issubset(set(config)):
        server = config['server']
        user = config['user']
        password = config['password']
    else:
        server = click.prompt('JIRA server address')
        user = click.prompt('User')
        password = click.prompt('Password', hide_input=True)

        if click.confirm('Do you want to save?'):
            config = get_config()
            config.update({
                'server': server,
                'user': user,
                'password': password
            })
            set_config(config)

    options = {'server': server}
    jira = JIRA(options, basic_auth=(user, password))

    return jira


def get_config():
    config_file_path = os.path.expanduser('~/.cliraconfig')
    if os.path.isfile(config_file_path):
        with open(config_file_path, 'r') as f:
            config_json = f.read()
            config = json.loads(config_json)

        return config

    return {}


def set_config(config):
    config_file_path = os.path.expanduser('~/.cliraconfig')
    with open(config_file_path, 'w') as f:
        config_json = json.dumps(config)
        f.write(config_json)



import click

from clira.commands.history import history
from clira.commands.time_report import time_report
from clira import utils


@click.group()
@click.pass_context
def cli(context):
    jira = utils.create_jira()

    context.obj = {
        'jira': jira
    }


cli.add_command(history)
cli.add_command(time_report)


if __name__ == "__main__":
    cli()



from setuptools import setup


setup(
    name = 'clira',
    packages = ['clira'], # this must be the same as the name above
    version = '0.1.4',
    description = 'Command line client for Jira',
    author = 'Paweł Jastrzębski',
    author_email = 'jastrzab5@gmail.com',
    url = 'https://gitlab.com/havk/clira', # use the URL to the github repo
    download_url = 'https://gitlab.com/havk/clira/repository/archive.tar.gz?ref=0.1.4', # I'll explain this in a second
    keywords = ['JIRA', 'jira', 'terminal', 'cli'], # arbitrary keywords
    classifiers = [],
    install_requires=[
        'jira==1.0.10',
        'click==6.7',
        'arrow==0.10.0'
    ],
    entry_points={
        'console_scripts': [
            'clira=clira.cli:cli'
        ]
    }
)
